"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@collectable/core");
const internals_1 = require("../internals");
function first(tree) {
    if (tree._size === 0)
        return void 0;
    var node = tree._root;
    while (!internals_1.isNone(node._left)) {
        node = node._left;
    }
    return node;
}
exports.first = first;
/**
 * Retrieves the first key in the tree, or undefined if the tree is empty.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTree<K, V>} tree The input tree
 * @returns {(K|undefined)} The first key in the tree, or undefined if the tree is empty
 */
function firstKey(tree) {
    var node = first(tree);
    return core_1.isDefined(node) ? node.key : void 0;
}
exports.firstKey = firstKey;
/**
 * Retrieves the value of the first entry in the tree, or undefined if the tree is empty.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTree<K, V>} tree The input tree
 * @returns {(K|undefined)} The value of the first entry in the tree, or undefined if the tree is empty
 */
function firstValue(tree) {
    var node = first(tree);
    return core_1.isDefined(node) ? node.value : void 0;
}
exports.firstValue = firstValue;
function iterateFromFirst(tree) {
    var path = internals_1.PathNode.NONE;
    var node = tree._root;
    while (!internals_1.isNone(node)) {
        path = internals_1.PathNode.next(node, path, 1 /* LEFT */);
        node = node._left;
    }
    return new internals_1.RedBlackTreeIterator(path, false);
}
exports.iterateFromFirst = iterateFromFirst;

//# sourceMappingURL=first.js.map
